==> xsns_1.0.1.zip: xsns_1.0.1/xoops_trust_path/modules/xsns/act/index/join_execAction.php <==
<?php
class join_execAction extends indexAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	
	if($this->isGuest() || !$this->validateToken('COMMUNITY_JOIN')){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$cid = $this->getIntRequest('cid', APP_REQUEST_GET);
	if(!isset($cid)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// ߥ˥ƥμ
	$perm = _CM_AUTH_NON_MEMBER;
	$commu_handler =& CM_CommunityHandler::getInstance();
	$community =& $commu_handler->get($cid);
	if(!is_object($community) || !$community->checkAuthority($perm)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$public_flag = $community->getVar('public_flag');
	$is_public = true;
	$name = $community->getVar('name');
	$redirect_url = _CM_URL_COMMU.'?cid='.$cid;
	
	if($public_flag > 1){
		// äκݤ˴Ԥξǧɬפʥߥ˥ƥ
		
		// Ѥߤɤγǧ
		$uid_admin = $community->getVar('uid_admin');
		$confirm_handler =& CM_ConfirmHandler::getInstance();
		if($confirm_handler->get($cid, $own_uid, $uid_admin, 0)){
			redirect_header($redirect_url, 2, _CM_INDEX_JOIN_REQ_NG_ALREADY);
		}
		
		// 
		$new_confirm =& $confirm_handler->create();
		$new_confirm->setVars(array(
			'c_commu_id' => $cid,
			'uid_from' => $own_uid,
			'uid_to' => $uid_admin,
			'mode' => 0,	// ߥ˥ƥ
			'r_datetime' => date('Y-m-d H:i:s'),
			'message' => $this->getTextRequest('message'),
		));
		
		if($confirm_handler->insert($new_confirm)){
			redirect_header($redirect_url, 2, sprintf(_CM_INDEX_JOIN_REQ_OK, $name));
		}
		redirect_header($redirect_url, 2, _CM_INDEX_JOIN_REQ_NG);
	}
	else{
		// ïǤ⻲òǽʥߥ˥ƥ
		
		$c_member_handler =& CM_MemberHandler::getInstance();
		$new_member =& $c_member_handler->create();
		$new_member->setVars(array(
			'uid' => $own_uid,
			'c_commu_id' => $cid,
			'r_datetime' => date('Y-m-d H:i:s'),
		));
		
		if($c_member_handler->insert($new_member)){
			redirect_header($redirect_url, 2, sprintf(_CM_INDEX_JOIN_OK, $name));
		}
		redirect_header($redirect_url, 2, _CM_INDEX_JOIN_NG);
	}
}

}
?>

==> xsns_1.0.3.zip: xsns_1.0.3/xoops_trust_path/modules/xsns/act/index/join_execAction.php <==
<?php
class join_execAction extends indexAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	
	if($this->isGuest() || !$this->validateToken('COMMUNITY_JOIN')){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$cid = $this->getIntRequest('cid');
	if(!isset($cid)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// ߥ˥ƥμ
	$perm = _CM_AUTH_NON_MEMBER;
	$commu_handler =& CM_CommunityHandler::getInstance();
	$community =& $commu_handler->get($cid);
	if(!is_object($community) || !$community->checkAuthority($perm)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$public_flag = $community->getVar('public_flag');
	$is_public = true;
	$name = $community->getVar('name');
	$redirect_url = _CM_URL_COMMU.'?cid='.$cid;
	
	if($public_flag > 1){
		// äκݤ˴Ԥξǧɬפʥߥ˥ƥ
		
		// Ѥߤɤγǧ
		$uid_admin = $community->getVar('uid_admin');
		$confirm_handler =& CM_ConfirmHandler::getInstance();
		if($confirm_handler->get($cid, $own_uid, $uid_admin, 0)){
			redirect_header($redirect_url, 2, _CM_INDEX_JOIN_REQ_NG_ALREADY);
		}
		
		// 
		$new_confirm =& $confirm_handler->create();
		$new_confirm->setVars(array(
			'c_commu_id' => $cid,
			'uid_from' => $own_uid,
			'uid_to' => $uid_admin,
			'mode' => 0,	// ߥ˥ƥ
			'r_datetime' => date('Y-m-d H:i:s'),
			'message' => $this->getTextRequest('message'),
		));
		
		if($confirm_handler->insert($new_confirm)){
			redirect_header($redirect_url, 2, sprintf(_CM_INDEX_JOIN_REQ_OK, $name));
		}
		redirect_header($redirect_url, 2, _CM_INDEX_JOIN_REQ_NG);
	}
	else{
		// ïǤ⻲òǽʥߥ˥ƥ
		
		$c_member_handler =& CM_MemberHandler::getInstance();
		$new_member =& $c_member_handler->create();
		$new_member->setVars(array(
			'uid' => $own_uid,
			'c_commu_id' => $cid,
			'r_datetime' => date('Y-m-d H:i:s'),
		));
		
		if($c_member_handler->insert($new_member)){
			redirect_header($redirect_url, 2, sprintf(_CM_INDEX_JOIN_OK, $name));
		}
		redirect_header($redirect_url, 2, _CM_INDEX_JOIN_NG);
	}
}

}
?>
